@@ -12,12 +12,11 @@ import trollius as asyncio
 from trollius import Return, From
 from trollius import base_events
 from trollius import constants
+from trollius import test_support as support
 from trollius import test_utils
 from trollius.py33_exceptions import BlockingIOError
 from trollius.test_utils import mock
-from trollius import test_support as support   # IPV6_ENABLED, gc_collect
 from trollius.time_monotonic import time_monotonic
-from trollius.test_support import assert_python_ok
 
 
 MOCK_ANY = mock.ANY
@@ -582,12 +581,12 @@ class BaseEventLoopTests(test_utils.TestCase):
             'loop = trollius.get_event_loop()',
             'print(loop.get_debug())'))
 
-        sts, stdout, stderr = assert_python_ok('-c', code,
-                                               TROLLIUSDEBUG='')
+        sts, stdout, stderr = support.assert_python_ok('-c', code,
+                                                       TROLLIUSDEBUG='')
         self.assertEqual(stdout.rstrip(), b'False')
 
-        sts, stdout, stderr = assert_python_ok('-c', code,
-                                               TROLLIUSDEBUG='1')
+        sts, stdout, stderr = support.assert_python_ok('-c', code,
+                                                       TROLLIUSDEBUG='1')
         self.assertEqual(stdout.rstrip(), b'True')
 
     def test_create_task(self):
@@ -633,6 +632,31 @@ class BaseEventLoopTests(test_utils.TestCase):
 
         self.assertFalse(self.loop.call_exception_handler.called)
 
+    def test_run_until_complete_baseexception(self):
+        # Python issue #22429: run_until_complete() must not schedule a pending
+        # call to stop() if the future raised a BaseException
+        @asyncio.coroutine
+        def raise_keyboard_interrupt():
+            raise KeyboardInterrupt
+
+        self.loop._process_events = mock.Mock()
+
+        try:
+            self.loop.run_until_complete(raise_keyboard_interrupt())
+        except KeyboardInterrupt:
+            pass
+
+        def func():
+            self.loop.stop()
+            func.called = True
+        func.called = False
+        try:
+            self.loop.call_soon(func)
+            self.loop.run_forever()
+        except KeyboardInterrupt:
+            pass
+        self.assertTrue(func.called)
+
 
 class MyProto(asyncio.Protocol):
     done = None
