@@ -1,8 +1,6 @@
 """Tests for selector_events.py"""
 
 import errno
-#import gc
-#import pprint
 import socket
 import sys
 import unittest
@@ -28,6 +26,7 @@ from trollius.selector_events import _SelectorTransport
 from trollius.selector_events import _SSL_REQUIRES_SELECT
 from trollius.test_utils import mock
 
+
 if sys.version_info >= (3,):
     UNICODE_STR = 'unicode'
 else:
@@ -1430,7 +1429,7 @@ class SelectorSslTransportTests(test_utils.TestCase):
         self.assertEqual(tr._conn_lost, 1)
         self.assertEqual(1, self.loop.remove_reader_count[1])
 
-    @test_utils.skipIf(ssl is None or not HAS_SNI, 'No SNI support')
+    @test_utils.skipIf(ssl is None, 'No SSL support')
     def test_server_hostname(self):
         _SelectorSslTransport(
             self.loop, self.sock, self.protocol, self.sslcontext,
