@@ -12,7 +12,6 @@ from trollius import From, Return
 from trollius import coroutines
 from trollius import test_support as support
 from trollius import test_utils
-from trollius.test_support import assert_python_ok
 from trollius.test_utils import mock
 
 
@@ -1775,14 +1774,14 @@ class GatherTestsBase:
             'import trollius.coroutines',
             'print(trollius.coroutines._DEBUG)'))
 
-        sts, stdout, stderr = assert_python_ok('-c', code,
-                                               TROLLIUSDEBUG='',
-                                               PYTHONPATH=aio_path)
+        sts, stdout, stderr = support.assert_python_ok('-c', code,
+                                                       TROLLIUSDEBUG='',
+                                                       PYTHONPATH=aio_path)
         self.assertEqual(stdout.rstrip(), b'False')
 
-        sts, stdout, stderr = assert_python_ok('-c', code,
-                                               TROLLIUSDEBUG='1',
-                                               PYTHONPATH=aio_path)
+        sts, stdout, stderr = support.assert_python_ok('-c', code,
+                                                       TROLLIUSDEBUG='1',
+                                                       PYTHONPATH=aio_path)
         self.assertEqual(stdout.rstrip(), b'True')
 
 
