@@ -108,6 +108,16 @@ def _raise_stop_error(*args):
     raise _StopError
 
 
+def _run_until_complete_cb(fut):
+    exc = fut._exception
+    if (isinstance(exc, BaseException)
+    and not isinstance(exc, Exception)):
+        # Issue #22429: run_forever() already finished, no need to
+        # stop it.
+        return
+    _raise_stop_error()
+
+
 class Server(events.AbstractServer):
 
     def __init__(self, loop, sockets):
@@ -182,6 +192,7 @@ class BaseEventLoop(events.AbstractEventLoop):
 
         Return a task object.
         """
+        self._check_closed()
         task = tasks.Task(coro, loop=self)
         if task._source_traceback:
             del task._source_traceback[-1]
@@ -272,7 +283,7 @@ class BaseEventLoop(events.AbstractEventLoop):
             # is no need to log the "destroy pending task" message
             future._log_destroy_pending = False
 
-        future.add_done_callback(_raise_stop_error)
+        future.add_done_callback(_run_until_complete_cb)
         try:
             self.run_forever()
         except:
@@ -282,7 +293,7 @@ class BaseEventLoop(events.AbstractEventLoop):
                 # local task.
                 future.exception()
             raise
-        future.remove_done_callback(_raise_stop_error)
+        future.remove_done_callback(_run_until_complete_cb)
         if not future.done():
             raise RuntimeError('Event loop stopped before Future completed.')
 
@@ -365,6 +376,7 @@ class BaseEventLoop(events.AbstractEventLoop):
         if (coroutines.iscoroutine(callback)
         or coroutines.iscoroutinefunction(callback)):
             raise TypeError("coroutines cannot be used with call_at()")
+        self._check_closed()
         if self._debug:
             self._assert_is_current_event_loop()
         timer = events.TimerHandle(when, callback, args, self)
@@ -395,6 +407,7 @@ class BaseEventLoop(events.AbstractEventLoop):
             raise TypeError("coroutines cannot be used with call_soon()")
         if self._debug and check_loop:
             self._assert_is_current_event_loop()
+        self._check_closed()
         handle = events.Handle(callback, args, self)
         if handle._source_traceback:
             del handle._source_traceback[-1]
@@ -412,7 +425,7 @@ class BaseEventLoop(events.AbstractEventLoop):
         """
         try:
             current = events.get_event_loop()
-        except AssertionError:
+        except RuntimeError:
             return
         if current is not self:
             raise RuntimeError(
@@ -431,6 +444,7 @@ class BaseEventLoop(events.AbstractEventLoop):
         if (coroutines.iscoroutine(callback)
         or coroutines.iscoroutinefunction(callback)):
             raise TypeError("coroutines cannot be used with run_in_executor()")
+        self._check_closed()
         if isinstance(callback, events.Handle):
             assert not args
             assert not isinstance(callback, events.TimerHandle)
