@@ -23,7 +23,7 @@ from . import events
 from . import executor
 from . import futures
 from .locks import Lock, Condition, Semaphore, _ContextManager
-from .coroutines import coroutine, From, Return, iscoroutinefunction, iscoroutine
+from .coroutines import coroutine, From, Return
 
 
 _PY34 = (sys.version_info >= (3, 4))
@@ -54,6 +54,10 @@ class Task(futures.Future):
     # all running event loops.  {EventLoop: Task}
     _current_tasks = {}
 
+    # If False, don't log a message if the task is destroyed whereas its
+    # status is still pending
+    _log_destroy_pending = True
+
     @classmethod
     def current_task(cls, loop=None):
         """Return the currently running task in an event loop or None.
@@ -86,9 +90,6 @@ class Task(futures.Future):
         self._must_cancel = False
         self._loop.call_soon(self._step)
         self.__class__._all_tasks.add(self)
-        # If False, don't log a message if the task is destroyed whereas its
-        # status is still pending
-        self._log_destroy_pending = True
 
     # On Python 3.3 or older, objects with a destructor that are part of a
     # reference cycle are never destroyed. That's not the case any more on
@@ -122,7 +123,7 @@ class Task(futures.Future):
     def get_stack(self, limit=None):
         """Return the list of stack frames for this task's coroutine.
 
-        If the coroutine is active, this returns the stack where it is
+        If the coroutine is not done, this returns the stack where it is
         suspended.  If the coroutine has completed successfully or was
         cancelled, this returns an empty list.  If the coroutine was
         terminated by an exception, this returns the list of traceback
@@ -292,7 +293,7 @@ class Task(futures.Future):
             elif isinstance(result, coroutines.FromWrapper):
                 result = result.obj
 
-            if iscoroutine(result):
+            if coroutines.iscoroutine(result):
                 # "yield coroutine" creates a task, the current task
                 # will wait until the new task is done
                 result = self._loop.create_task(result)
