@@ -390,7 +390,7 @@ class IocpProactor(object):
             wrap_error(ov.getresult)
             return pipe
 
-        # FIXME: Tulip issue 196: why to we neeed register=False?
+        # FIXME: Tulip issue 196: why do we need register=False?
         # See also the comment in the _register() method
         return self._register(ov, pipe, finish_accept_pipe,
                               register=False)
@@ -419,6 +419,11 @@ class IocpProactor(object):
         return self._register(ov, None, finish_connect_pipe, wait_for_post=True)
 
     def wait_for_handle(self, handle, timeout=None):
+        """Wait for a handle.
+
+        Return a Future object. The result of the future is True if the wait
+        completed, or False if the wait did not complete (on timeout).
+        """
         if timeout is None:
             ms = _winapi.INFINITE
         else:
